@@ -62,7 +62,7 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     feature_df['Answer_Status'] = completion_status_binary
 
     # - Loading Participants Information
-    info_dict = utils.load_participant_study_info.execute(intermediate_participant_path, output_dir_path)
+    info_dict = utils.load_participant_study_info.execute(intermediate_participant_path, output_dir_path, lsf_json_folder_path)
 
     # - feature 1: Day of the week
     feature1 = feature_engineering_ema.day_of_the_week.create_column(df_prompt['Actual_Prompt_Local_DateTime'], print_stats)
@@ -82,11 +82,12 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     feature_df['match_time_battery'] = match_time_battery
 
     # - feature 5: GPS location
-    feature7, match_time_location = feature_engineering_ema.location.create_column(df_prompt['Actual_Prompt_Local_DateTime'],
+    feature7, match_time_location, feature7_1 = feature_engineering_ema.location.create_column(participant_id, df_prompt['Actual_Prompt_Local_DateTime'], info_dict,
                                                                                    intermediate_participant_path,
                                                                                    date_in_study, decryption_password)
     feature_df['LOCATION'] = feature7
     feature_df['match_time_location'] = match_time_location
+    feature_df['DISTANCE_FROM_HOME'] = feature7_1
 
     # - feature 6: Location label
     feature8 = feature_engineering_ema.location_label.create_column(lsf_json_folder_path, participant_id, feature7)
